import * as cdk from "@aws-cdk/core";
import * as iam from "@aws-cdk/aws-iam";
import * as route53 from "@aws-cdk/aws-route53";
import { IAccountProps } from "./account";
/**
 * Properties for RootDns
 */
export interface RootDnsProps {
    /**
     * An array storing details about each stage accounts
     */
    readonly stagesDetails: Array<IAccountProps>;
    /**
     * The top level domain name
     */
    readonly rootHostedZoneDNSName: string;
    /**
     * A boolean indicating if Domain name has already been registered to a third party or if you want this contruct to create it (the latter is not yet supported)
     */
    readonly thirdPartyProviderDNSUsed?: boolean;
}
/**
 * A class creating the main hosted zone and a role assumable by stages account to be able to set sub domain delegation
 */
export declare class RootDns extends cdk.Construct {
    rootHostedZone: route53.IHostedZone;
    dnsAutoUpdateRole: iam.Role;
    constructor(scope: cdk.Construct, id: string, props: RootDnsProps);
    createDNSAutoUpdateRole(props: RootDnsProps): iam.Role;
    createRootHostedZone(props: RootDnsProps): route53.HostedZone;
}
